@@ -140,7 +140,6 @@ class Petrinet:
 
     def create_transitions(self):
         # creating the transition list
-        self.transitions = []
         for c, label in enumerate(self.new_labels):
             self.transitions.append(f"T_{c}")
             if label[5] == -1:
@@ -212,14 +211,6 @@ class Petrinet:
             arc = '''["''' + '''" "'''.join(arclist) + '''"]'''
             newarc = newarc + arc
         newarc = newarc + ''']'''
-        newlabel = '''['''
-        for t in self.names_transitions:
-            label = '''[\'''' + '''' \"'''.join(t) + '''"]'''
-            newlabel = newlabel + label
-        newlabel = newlabel + ''']'''
-
-        string = f'''CONFORMANCE({tablename}, {place}, {transition}, {newarc}, {newlabel}, {s_e} )'''
+        string = f"CONFORMANCE({tablename}, {place}, {transition}, {newarc}, {s_e} )"
         return string
 
-    def pmpy_out(self):
-        return "Output Dummy"
